=== modified file 'bzrlib/info.py'
--- bzrlib/info.py	2011-12-18 15:28:38 +0000
+++ bzrlib/info.py	2012-01-18 20:47:13 +0000
@@ -352,7 +352,7 @@
     except (NoWorkingTree, NotLocalUrl, NotBranchError):
         tree = None
         try:
-            branch = a_bzrdir.open_branch()
+            branch = a_bzrdir.open_branch(name="")
         except NotBranchError:
             branch = None
             try:
@@ -442,8 +442,13 @@
             phrase = 'Shared repository'
         else:
             phrase = 'Unshared repository'
+        extra = []
         if repository.make_working_trees():
-            phrase += ' with trees'
+            extra.append('trees')
+        if len(control.get_branches()) > 0:
+            extra.append('colocated branches')
+        if extra:
+            phrase += ' with ' + " and ".join(extra)
         return phrase
     else:
         if repository.is_shared():

=== modified file 'bzrlib/tests/blackbox/test_info.py'
--- bzrlib/tests/blackbox/test_info.py	2011-12-14 20:21:52 +0000
+++ bzrlib/tests/blackbox/test_info.py	2012-01-18 20:47:13 +0000
@@ -1097,6 +1097,22 @@
        ), out)
         self.assertEqual('', err)
 
+    def test_info_unshared_repository_with_colocated_branches(self):
+        format = bzrdir.format_registry.make_bzrdir('development-colo')
+        transport = self.get_transport()
+
+        # Create unsahred repository
+        repo = self.make_repository('repo', shared=False, format=format)
+        repo.set_make_working_trees(True)
+        repo.bzrdir.create_branch(name='foo')
+        out, err = self.run_bzr('info repo')
+        self.assertEqualDiff(
+"""Unshared repository with trees and colocated branches (format: development-colo)
+Location:
+  repository: repo
+""", out)
+        self.assertEqual('', err)
+
     def assertCheckoutStatusOutput(self,
         command_string, lco_tree, shared_repo=None,
         repo_branch=None,

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2012-01-18 10:42:07 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2012-01-18 20:47:13 +0000
@@ -26,6 +26,9 @@
 .. Improvements to existing commands, especially improved performance 
    or memory usage, or better results.
 
+* ``bzr info`` now reports when there are present (but unused) colocated
+  branches. (Jelmer Vernooij, #891646)
+
 Bug Fixes
 *********
 

